==> ejc-zatopbpm-impl-3.0.0-20230919.072812-26-sources.jar: com/ejianc/zatopbpm/vo/BpmInfoVO.java <==
package com.ejianc.zatopbpm.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 审批信息表
 * 
 * @author generator
 * 
 */
public class BpmInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long billId; // 单据id
    private String billTypeCode; // 单据类型编码
    private String bpmId; // 审批id
    private String zatopUrl; // 第三方流程的页面url
    private String pcurl; // 单据pc端路由
    private String maurl; // 单据移动端路由
    private String type; // 流程状态--与第三方流程同步
    private String userid; // 用户编码
    private String zatopbpmVersion; // 业务对象对应的版本(第三方系统使用判断校验)

    private Long orgId; // 提交组织id

    private String orgSourceId; // 单据移动端路由
    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBpmId() {
        return bpmId;
    }

    public void setBpmId(String bpmId) {
        this.bpmId = bpmId;
    }
    public String getZatopUrl() {
        return zatopUrl;
    }

    public void setZatopUrl(String zatopUrl) {
        this.zatopUrl = zatopUrl;
    }
    public String getPcurl() {
        return pcurl;
    }

    public void setPcurl(String pcurl) {
        this.pcurl = pcurl;
    }
    public String getMaurl() {
        return maurl;
    }

    public void setMaurl(String maurl) {
        this.maurl = maurl;
    }
    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }
    public String getZatopbpmVersion() {
        return zatopbpmVersion;
    }

    public void setZatopbpmVersion(String zatopbpmVersion) {
        this.zatopbpmVersion = zatopbpmVersion;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
}

==> ejc-zatopbpm-impl-3.0.0-20231012.032030-70-sources.jar: com/ejianc/zatopbpm/vo/BpmInfoVO.java <==
package com.ejianc.zatopbpm.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 审批信息表
 * 
 * @author generator
 * 
 */
public class BpmInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long billId; // 单据id
    private String billTypeName; // 单据类型名称
    private String billTypeCode; // 单据类型编码
    private String bpmId; // 审批id
    private String zatopUrl; // 第三方流程的页面url
    private String pcurl; // 单据pc端路由
    private String maurl; // 单据移动端路由
    private String type; // 流程状态--与第三方流程同步
    private Long userId; // 用户id
    private String userCode; // 用户编码
    private String userName; // 用户名称
    private String zatopbpmVersion; // 业务对象对应的版本(第三方系统使用判断校验)

    private String billCode; // 单据编码
    private Long orgId; // 提交组织id

    private String orgSourceId; // 单据移动端路由
    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBpmId() {
        return bpmId;
    }

    public void setBpmId(String bpmId) {
        this.bpmId = bpmId;
    }
    public String getZatopUrl() {
        return zatopUrl;
    }

    public void setZatopUrl(String zatopUrl) {
        this.zatopUrl = zatopUrl;
    }
    public String getPcurl() {
        return pcurl;
    }

    public void setPcurl(String pcurl) {
        this.pcurl = pcurl;
    }
    public String getMaurl() {
        return maurl;
    }

    public void setMaurl(String maurl) {
        this.maurl = maurl;
    }
    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getZatopbpmVersion() {
        return zatopbpmVersion;
    }

    public void setZatopbpmVersion(String zatopbpmVersion) {
        this.zatopbpmVersion = zatopbpmVersion;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
}
